Glossary
========


.. list-table::
   :header-rows: 1

   * - Name
     - Description
	 
   * - model parameter
     - A feature in the model that is not controlled by the designer, but affects the model outputs, i.e. the solar irradiance.

   * - design variable
     - A feature in the model that is controlled by the designer and affects the model outputs, i.e. the capacity of the photovoltaic array.

   * - quantity of interest
     - The model output of interest, for which the stochastic features are quantified, i.e. mean, standard deviation, Sobol' indices.

   * - population
     - The set of design samples considered during the design optimization.

   * - fitness
     - The objective values for the design samples considered during the design optimization.

   * - objective
     - The goal of the optimization, i.e. the minimization of the carbon intensity mean.

   * - Sobol' indices
     - Sensitivity indices which quantify the contribution of the variance of the model inputs to the variance of the quantity of interest.

   * - hydrogen-based energy system
     - An energy system that produces and uses hydrogen as an energy carrier.

